<?php
/**
*
* @package phpBB Extension - AccessNotification by SiteGuarding.com
* @author SiteGuarding.com team 
* @copyright (C) 2017 SiteGuarding.com team (https://SiteGuarding.com)
*
*/

namespace siteguarding\accessnotification\event;


use Symfony\Component\EventDispatcher\EventSubscriberInterface;


class pan_listener implements EventSubscriberInterface
{
	protected $config;

	protected $log;

	protected $user;

	protected $auth;

	protected $request;

	protected $php_ext;

	protected $phpbb_root_path;

	public function __construct(\phpbb\config\config $config, \phpbb\log\log $log, \phpbb\user $user, \phpbb\auth\auth $auth, \phpbb\db\driver\driver_interface $db,$request, $php_ext, $phpbb_root_path)
	{
		$this->config	= $config;
		$this->log		= $log;
		$this->user		= $user;
		$this->auth		= $auth;
		$this->db		= $db;
		$this->request = $request;
		$this->php_ext  = $php_ext;
		$this->phpbb_root_path  = $phpbb_root_path;
	}

	static public function getSubscribedEvents()
	{
		return array(
		
			'core.user_setup'				=> 'load_language_on_setup',
			'core.auth_login_session_create_before' => 'send_login',
			
		);
	}	

	public function load_language_on_setup($event)
	{
		$lang_set_ext = $event['lang_set_ext'];
		$lang_set_ext[] = array(
			'ext_name' => 'siteguarding/accessnotification',
			'lang_set' => 'common',
		);
		$event['lang_set_ext'] = $lang_set_ext;
	}

	public function send_login($event)
	{
		$data = array(
			'lang'				=> basename($this->request->variable('lang', $this->user->lang_name)),
		);
		$statusEmail = $this->config['pan_enable'] ? $this->config['pan_enable'] : '';
		$email = $this->config['pan_email'] ? $this->config['pan_email'] : '';
		$token = $this->config['pan_telegram_token'] ? $this->config['pan_telegram_token'] : '';
		$chatId = $this->config['pan_telegram_chat_id'] ? $this->config['pan_telegram_chat_id'] : '';
		$successAttempts = $this->config['pan_send_success'] ? $this->config['pan_send_success'] : '';
		$failAttempts = $this->config['pan_send_failed'] ? $this->config['pan_send_failed'] : '';
		$telegram = $this->config['pan_enable_telegram'] ? $this->config['pan_enable_telegram'] : '';
		$link = 'http://api.ipinfodb.com/v3/ip-city/?key=524ec42c675fe66c37cc26f5e289f98555be21e05720bda46e51da63aa58a2ca&ip='.$this->user->ip.'&format=json';
		$result = @file_get_contents($link);
		$geolocation = (array)@json_decode($result,true);
		$user		= $event['username'];
		$login		= $event['login'];
		$admin		= $event['admin'];
		$domain = $this->user->host;
		if ($login['error_msg'] === false) {
			$res = 'success';
			$resText = 'successful login';

		} else {
			$res = 'fault';
			$resText = 'failed login';
		}

		if ($admin && ($failAttempts || $successAttempts)) {
				  
			if ($statusEmail && $email != '') { 
				if (!class_exists('messenger'))
					{
						include($this->phpbb_root_path . 'includes/functions_messenger.' . $this->php_ext);
					}

				$messenger = new \messenger(false);

				if (strpos(strtolower($email), 'gmail') === false) {
					$messenger->template('@siteguarding_accessnotification/admin_notify_login', $data['lang']);
				} else {
					$messenger->template('@siteguarding_accessnotification/admin_notify_login_no_html', $data['lang']);
				}
				
				$messenger->to($email);
				$messenger->im($email);
				$messenger->assign_vars(array(
					'DOMAIN'		 => $domain,
					'TIME'		 => date("Y-m-d H:i:s"),
					'USER'		=> $user,
					'BROWSER'		 => $this->user->browser,
					'USER_IP'		=> $this->user->ip,
					'CITY'		=> $geolocation['cityName'],
					'COUNTRY'		=> $geolocation['countryName'],
					'RESULT'		=> $resText)
				);

				$messenger->from('phpBBUserAccessNotification', 'phpBBUserAccessNotification');
				$messenger->headers('Content-type: text/html');

			}
			
			if ($token != '' && $chatId != '' && $telegram) {
				$str = 'Date: ' . date("Y-m-d H:i:s"). "%0A%0A" . 
				'Someone has tried to login as <b>'.$user.'</b> to <b>'. $domain . "</b>" . "%0A%0A" . 
				'If you didn\'t login, please <b>change your password</b> and contact website support team.' . "%0A%0A" .
				'IP: ' . $this->user->ip . "%0A" . 
				'Country: ' . $geolocation['countryName'] . ', ' . $geolocation['cityName']. "%0A" . 
				'Login result: ' . $resText . "%0A%0A" . 
				'Plugin developed by siteguarding.com';						
			}
				
				
			if ($successAttempts && $failAttempts) {
				if ($token != '' && $chatId != '' && $telegram) $fp=fopen("https://api.telegram.org/bot{$token}/sendMessage?chat_id={$chatId}&parse_mode=html&text={$str}","r");
				if ($statusEmail && $email != '') $messenger->send(NOTIFY_EMAIL);
			} elseif ($successAttempts && !$failAttempts) {
				if ($res == 'success') {
					if ($token != '' && $chatId != '' && $telegram) $fp=fopen("https://api.telegram.org/bot{$token}/sendMessage?chat_id={$chatId}&parse_mode=html&text={$str}","r");
					if ($statusEmail && $email != '') $messenger->send(NOTIFY_EMAIL);
				}
			} elseif (!$successAttempts && $failAttempts) {
				if ($res == 'fault') {
					if ($token != '' && $chatId != '' && $telegram) $fp=fopen("https://api.telegram.org/bot{$token}/sendMessage?chat_id={$chatId}&parse_mode=html&text={$str}","r");
					if ($statusEmail && $email != '') $messenger->send(NOTIFY_EMAIL);
				}
			}
			
		}	

	}

}
